@@ -18,10 +18,10 @@
 # ./make_release <place> <version>
 #
 # For example
-# ./make_release /tags/ahven_1_0 1.0
+# ./make_release AHVEN_1_0_BASE 1.0
 #
 
-SVNROOT=http://svn.gna.org/svn/ahven
+export CVSROOT=:pserver:anonymous@ahven.cvs.sourceforge.net:/cvsroot/ahven
 
 failure()
 {
@@ -38,9 +38,20 @@ PLACE=$1
 VERSION=$2
 
 cd /tmp || failure "cd /tmp failed"
-svn export $SVNROOT/$PLACE ahven-$VERSION || failure "checkout failed"
+# svn export $SVNROOT/$PLACE ahven-$VERSION || failure "checkout failed"
+
+cvs -d$CVSROOT login || failure "cvs login failed"
+cvs -z3 -d$CVSROOT export -r $PLACE -d ahven-$VERSION ahven || failure "cvs export failed"
+
 tar zcf ahven-$VERSION.tar.gz ahven-$VERSION || failure "tar zcf failed"
+zip -r ahven-$VERSION.zip ahven-$VERSION || failure "zip -r failed"
 
 echo "Release tarball ready at /tmp/ahven-$VERSION.tar.gz"
+echo "Release zip ready at /tmp/ahven-$VERSION.zip"
 echo "Please remove /tmp/ahven-$VERSION directory."
 
+echo
+echo "Sign the tarball and the zip with commands"
+echo "gpg --detach /tmp/ahven-$VERSION.tar.gz"
+echo "gpg --detach /tmp/ahven-$VERSION.zip"
+
